@@ -1,5 +1,7 @@
 # flake8: noqa: F401
-from .calibration_model import CalibrationModel
 from .extraction_model import ExtractionModel
+from .calibration_model import CalibrationModel
+from .peak_selection_model import PeakSelectionModel
+from .evaluation_model import EvaluationModel
 from .orientation import Orientation
 from . import setup
